@@ -162,7 +162,7 @@ class CreateVolumeBackup(command.ShowOne):
 
             kwargs['availability_zone'] = parsed_args.availability_zone
 
-        columns = (
+        columns: tuple[str, ...] = (
             "id",
             "name",
             "volume_id",
@@ -298,7 +298,7 @@ class ListVolumeBackup(command.Lister):
     def take_action(self, parsed_args):
         volume_client = self.app.client_manager.sdk_connection.volume
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'name',
             'description',
@@ -307,7 +307,7 @@ class ListVolumeBackup(command.Lister):
             'is_incremental',
             'created_at',
         )
-        column_headers = (
+        column_headers: tuple[str, ...] = (
             'ID',
             'Name',
             'Description',
@@ -403,8 +403,7 @@ class RestoreVolumeBackup(command.ShowOne):
             "--force",
             action="store_true",
             help=_(
-                "Restore the backup to an existing volume "
-                "(default to False)"
+                "Restore the backup to an existing volume (default to False)"
             ),
         )
         return parser
@@ -412,7 +411,7 @@ class RestoreVolumeBackup(command.ShowOne):
     def take_action(self, parsed_args):
         volume_client = self.app.client_manager.sdk_connection.volume
 
-        columns = (
+        columns: tuple[str, ...] = (
             'id',
             'volume_id',
             'volume_name',
@@ -466,7 +465,7 @@ class SetVolumeBackup(command.Command):
             '--name',
             metavar='<name>',
             help=_(
-                'New backup name'
+                'New backup name '
                 '(supported by --os-volume-api-version 3.9 or above)'
             ),
         )
@@ -655,7 +654,7 @@ class ShowVolumeBackup(command.ShowOne):
     def take_action(self, parsed_args):
         volume_client = self.app.client_manager.sdk_connection.volume
         backup = volume_client.find_backup(parsed_args.backup)
-        columns = (
+        columns: tuple[str, ...] = (
             "availability_zone",
             "container",
             "created_at",
